c these are the bits and pieces to read the new block
c models, sb4l18/sb10l18. 
c Before you call this subroutine, make sure you copied
c the right files into the I/O files opened by this 
c subroutine:
c block.desc (either block.desc from sb4l18.dir or block.desc.sb10l18)
c block.model (the actual model either block.model from 
c             sb4l18.dir or one of block.sb10l18.s/block.sb10l18.p/
c             block.sb10l18.c).

c the main routine calls one subroutine to  read the model:
c call setup
c values as a function of radius, longitude and latitude
c are returned by real*4 function fval
c e.g. amap=fval(srad,scol,slong)
c where fval, srad, scol, slong have to be declared real*4
c the returned value is dvs/vs.
c
c there are two file names hardwired into the subroutines:
c 1) block.desc (to read the model description file)
c 2) block.model (the binary block model)
c
c gabi laske, December 1999
c 
      implicit real*8(a-h,o-z)

c single precision stuff
      real*4 srad,scol,slong,fval

      call setup

c loop over angout, the angle to be output
c choose radius between 3480 (CMB) and Moho (6348)
c
c choose longitude going from 0 to 360 deg
.
.
.
.
      print*,'enter radius, latitude, longitude'
      read(*,*)rad,flat,flong
      srad=rad
      scol=(90.-flat)
      slong=flong
      amap=fval(srad,scol,slong)
.
.
.
c this makes percentage dvs/vs
      write(*,*)srad,flat,slong,float(100.*amap)
.
.
.

      stop
      end

c################################################################################


      real*4 function fval(r0,t0,p0)
      common/blk$/block(50000),nblk
      call fblk(r0,t0,p0,ib)
      fval=block(ib)
      return
      end

      subroutine setup
      character*128 filename
      common/blocks/r1(30),r2(30),t1(180),t2(180),
     +    pmn(50000),pmx(50000),nshell,mshell,mlat(181),nlat
      common/blk$/block(50000),nblk
      call blks(nblk)
      filename= 
     +'block.model'
      open(9,file=filename, form='unformatted')
      read(9),n,phibar
      print*,'n,nblk,phibar',n,nblk,phibar
      read(9) iter,(block(i),i=1,n),phibar,r
      close(9)
      do 20 i=1,n
        if(abs(block(i)).lt.1.e-15) block(i)=1.
   20   continue
      do 30 i=n+1,nblk
   30   block(i)=1.
      return
      end

      subroutine blks(nblk)
c*** routine to establish block parameters
      common/blocks/r1(30),r2(30),t1(180),t2(180),
     +    pmn(50000),pmx(50000),nshell,mshell,mlat(181),nlat
      character*256 filename
      data rad/57.29578/
      filename=
     +'block.desc'
      open(12,file=filename)
c bsize=block size at equator
      read(12,*) bsize
      nlat=nint(180./bsize)
      bsize=180./nlat
c nshells = # shells
      read(12,*) nshell
      ib=0
      do 10 n=1,nshell
c rad1 and rad2 are lower and upper radii of shell
        read(12,*) rad1,rad2
        tmax=0.
        r1(n)=rad1
        r2(n)=rad2
        mlat(1)=0
        do 30 ii=1,nlat
        tmin=tmax
        tmax=tmin+bsize
        th=0.5*(tmin+tmax)/rad
        s1=sin(th)
        mlon=max(nint(360./bsize*s1),1)
        hsize=360./mlon
        pmax=0.
        do 35 jj=1,mlon
          pmin=pmax
          pmax=pmin+hsize
          ib=ib+1
          pmn(ib)=pmin
          pmx(ib)=pmax
   35     continue
        if(n.eq.1) then
           mlat(ii+1)=ib
           t1(ii)=tmin
           t2(ii)=tmax
        end if
   30   continue
      if(n.eq.1) mshell=ib
   10 continue
      nblk=ib
      close(12)
      return
      end

      subroutine fblk(r0,t0,p0,ib)
c*** routine to find block number given radial index and colat and long
      common/blocks/r1(30),r2(30),t1(180),t2(180),
     +    pmn(50000),pmx(50000),nshell,mshell,mlat(181),nlat
      do 10 i=1,nshell
      if(r0.ge.r1(i).and.r0.le.r2(i)) then
         n=i
         goto 20
      end if
   10 continue
      ib=-1
      return
   20 do 30 i=1,nlat
      if(t0.ge.t1(i).and.t0.le.t2(i)) then
         j1=(n-1)*mshell+mlat(i)+1
         j2=(n-1)*mshell+mlat(i+1)
         goto 40
      end if
   30 continue
      ib=-1
      return
   40 do 50 i=j1,j2
      if(p0.ge.pmn(i).and.p0.le.pmx(i)) then
         ib=i
         return
      end if
   50 continue
      ib=-1
      return
      end


